
From: Adrian Bunk <bunk@stusta.de>

This patch makes some needlessly global functions static.

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/linux/audit.h |   12 ------------
 25-akpm/kernel/audit.c        |   17 ++++++++++-------
 2 files changed, 10 insertions(+), 19 deletions(-)

diff -puN include/linux/audit.h~kernel-auditc-make-some-functions-static include/linux/audit.h
--- 25/include/linux/audit.h~kernel-auditc-make-some-functions-static	Tue Jan 18 14:34:53 2005
+++ 25-akpm/include/linux/audit.h	Tue Jan 18 14:34:53 2005
@@ -177,16 +177,10 @@ extern void		    audit_log_format(struct
 					     const char *fmt, ...)
 			    __attribute__((format(printf,2,3)));
 extern void		    audit_log_end(struct audit_buffer *ab);
-extern void		    audit_log_end_fast(struct audit_buffer *ab);
-extern void		    audit_log_end_irq(struct audit_buffer *ab);
 extern void		    audit_log_d_path(struct audit_buffer *ab,
 					     const char *prefix,
 					     struct dentry *dentry,
 					     struct vfsmount *vfsmnt);
-extern int		    audit_set_rate_limit(int limit);
-extern int		    audit_set_backlog_limit(int limit);
-extern int		    audit_set_enabled(int state);
-extern int		    audit_set_failure(int state);
 
 				/* Private API (for auditsc.c only) */
 extern void		    audit_send_reply(int pid, int seq, int type,
@@ -199,13 +193,7 @@ extern void		    audit_log_lost(const ch
 #define audit_log_vformat(b,f,a) do { ; } while (0)
 #define audit_log_format(b,f,...) do { ; } while (0)
 #define audit_log_end(b) do { ; } while (0)
-#define audit_log_end_fast(b) do { ; } while (0)
-#define audit_log_end_irq(b) do { ; } while (0)
 #define audit_log_d_path(b,p,d,v) do { ; } while (0)
-#define audit_set_rate_limit(l) do { ; } while (0)
-#define audit_set_backlog_limit(l) do { ; } while (0)
-#define audit_set_enabled(s) do { ; } while (0)
-#define audit_set_failure(s) do { ; } while (0)
 #endif
 #endif
 #endif
diff -puN kernel/audit.c~kernel-auditc-make-some-functions-static kernel/audit.c
--- 25/kernel/audit.c~kernel-auditc-make-some-functions-static	Tue Jan 18 14:34:53 2005
+++ 25-akpm/kernel/audit.c	Tue Jan 18 14:34:53 2005
@@ -150,6 +150,9 @@ struct audit_entry {
 	struct audit_rule rule;
 };
 
+static void audit_log_end_irq(struct audit_buffer *ab);
+static void audit_log_end_fast(struct audit_buffer *ab);
+
 static void audit_panic(const char *message)
 {
 	switch (audit_failure)
@@ -231,7 +234,7 @@ void audit_log_lost(const char *message)
 
 }
 
-int audit_set_rate_limit(int limit)
+static int audit_set_rate_limit(int limit)
 {
 	int old		 = audit_rate_limit;
 	audit_rate_limit = limit;
@@ -240,7 +243,7 @@ int audit_set_rate_limit(int limit)
 	return old;
 }
 
-int audit_set_backlog_limit(int limit)
+static int audit_set_backlog_limit(int limit)
 {
 	int old		 = audit_backlog_limit;
 	audit_backlog_limit = limit;
@@ -249,7 +252,7 @@ int audit_set_backlog_limit(int limit)
 	return old;
 }
 
-int audit_set_enabled(int state)
+static int audit_set_enabled(int state)
 {
 	int old		 = audit_enabled;
 	if (state != 0 && state != 1)
@@ -260,7 +263,7 @@ int audit_set_enabled(int state)
 	return old;
 }
 
-int audit_set_failure(int state)
+static int audit_set_failure(int state)
 {
 	int old		 = audit_failure;
 	if (state != AUDIT_FAIL_SILENT
@@ -560,7 +563,7 @@ static inline int audit_log_drain(struct
 }
 
 /* Initialize audit support at boot time. */
-int __init audit_init(void)
+static int __init audit_init(void)
 {
 	printk(KERN_INFO "audit: initializing netlink socket (%s)\n",
 	       audit_default ? "enabled" : "disabled");
@@ -781,7 +784,7 @@ static DECLARE_TASKLET(audit_tasklet, au
  * the audit buffer is places on a queue and a tasklet is scheduled to
  * remove them from the queue outside the irq context.  May be called in
  * any context. */
-void audit_log_end_irq(struct audit_buffer *ab)
+static void audit_log_end_irq(struct audit_buffer *ab)
 {
 	unsigned long flags;
 
@@ -796,7 +799,7 @@ void audit_log_end_irq(struct audit_buff
 
 /* Send the message in the audit buffer directly to user space.  May not
  * be called in an irq context. */
-void audit_log_end_fast(struct audit_buffer *ab)
+static void audit_log_end_fast(struct audit_buffer *ab)
 {
 	unsigned long flags;
 
_
